#[repr(transparent)]pub struct CaptureH(pub u32);Expand description
Local Capture High Register
Tuple Fields
0: u32Implementations
Sourceimpl CaptureH
impl CaptureH
Sourcepub const fn capture_value(&self) -> u32
pub const fn capture_value(&self) -> u32
A read reflects the value of the upper 32 bits of the central EVTIMER at the time the last capture signal was generated by the CPU. A separate pair of CAPTURE registers are implemented for each CPU. Each CPU reads its own capture value at the same pair of addresses.
Sourcepub const fn set_capture_value(&mut self, val: u32)
pub const fn set_capture_value(&mut self, val: u32)
A read reflects the value of the upper 32 bits of the central EVTIMER at the time the last capture signal was generated by the CPU. A separate pair of CAPTURE registers are implemented for each CPU. Each CPU reads its own capture value at the same pair of addresses.