nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

CaptureL

Struct CaptureL 

#[repr(transparent)]
pub struct CaptureL(pub u32);
Local Capture Low Register

Tuple Fields

0: u32

Implementations

Source

impl CaptureL

pub const fn capture_value(&self) -> u32

A read reflects the value of the lower 32 bits of the central EVTIMER at the time the last capture signal was generated by the CPU. A separate pair of CAPTURE registers are implemented for each CPU. Each CPU reads its own capture value at the same pair of addresses.

pub const fn set_capture_value(&mut self, val: u32)

A read reflects the value of the lower 32 bits of the central EVTIMER at the time the last capture signal was generated by the CPU. A separate pair of CAPTURE registers are implemented for each CPU. Each CPU reads its own capture value at the same pair of addresses.