#[repr(transparent)]pub struct Evtimerh(pub u32);Expand description
EVTIMER High Register
Tuple Fields
0: u32Implementations
Sourceimpl Evtimerh
impl Evtimerh
Sourcepub const fn evtimer_count_value(&self) -> u32
pub const fn evtimer_count_value(&self) -> u32
A read reflects the current value of the upper 32 bits of the EVTIMER. Note there is physically only one EVTimer, readable from all domains.
Sourcepub const fn set_evtimer_count_value(&mut self, val: u32)
pub const fn set_evtimer_count_value(&mut self, val: u32)
A read reflects the current value of the upper 32 bits of the EVTIMER. Note there is physically only one EVTimer, readable from all domains.