#[repr(transparent)]pub struct Evtimerl(pub u32);Expand description
EVTIMER Low Register
Tuple Fields
0: u32Implementations
Sourceimpl Evtimerl
impl Evtimerl
Sourcepub const fn evtimer_count_value(&self) -> u32
pub const fn evtimer_count_value(&self) -> u32
A read reflects the current value of the lower 32 bits of the EVTIMER. Note there is physically only one EVTimer, readable from all domains.
Sourcepub const fn set_evtimer_count_value(&mut self, val: u32)
pub const fn set_evtimer_count_value(&mut self, val: u32)
A read reflects the current value of the lower 32 bits of the EVTIMER. Note there is physically only one EVTimer, readable from all domains.