nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

MatchH

Struct MatchH 

#[repr(transparent)]
pub struct MatchH(pub u32);
Match High Register

Tuple Fields

0: u32

Implementations

Source

impl MatchH

pub const fn match_value(&self) -> u32

The value written to the MATCH (L/H) register pair is compared against the central EVTIMER. When a match occurs, an interrupt request is generated if enabled. A separate pair of MATCH registers are implemented for each CPU. Each CPU reads its own local value at the same pair of addresses.

pub const fn set_match_value(&mut self, val: u32)

The value written to the MATCH (L/H) register pair is compared against the central EVTIMER. When a match occurs, an interrupt request is generated if enabled. A separate pair of MATCH registers are implemented for each CPU. Each CPU reads its own local value at the same pair of addresses.