#[repr(transparent)]pub struct OseventCtrl(pub u32);Expand description
OS_EVENT TIMER Control Register
Tuple Fields
0: u32Implementations
Sourceimpl OseventCtrl
impl OseventCtrl
Sourcepub const fn ostimer_intrflag(&self) -> bool
pub const fn ostimer_intrflag(&self) -> bool
This bit is set when a match occurs between the central 64-bit EVTIMER and the value programmed in the Match-register pair for the associated CPU This bit is cleared by writing a ‘1’. Writes to clear this bit are asynchronous. This should be done before a new match value is written into the MATCH_L/H registers
Sourcepub const fn set_ostimer_intrflag(&mut self, val: bool)
pub const fn set_ostimer_intrflag(&mut self, val: bool)
This bit is set when a match occurs between the central 64-bit EVTIMER and the value programmed in the Match-register pair for the associated CPU This bit is cleared by writing a ‘1’. Writes to clear this bit are asynchronous. This should be done before a new match value is written into the MATCH_L/H registers
Sourcepub const fn ostimer_intena(&self) -> bool
pub const fn ostimer_intena(&self) -> bool
When this bit is ‘1’ an interrupt/wakeup request to the Domainn processor will be asserted when the OSTIMER_INTR flag is set. When this bit is ‘0’, interrupt/wakeup requests due to the OSTIMER_INTR flag are blocked.A separate OSEVENT_CTRL register is implemented for each CPU. Each CPU reads its own local value at the same address.
Sourcepub const fn set_ostimer_intena(&mut self, val: bool)
pub const fn set_ostimer_intena(&mut self, val: bool)
When this bit is ‘1’ an interrupt/wakeup request to the Domainn processor will be asserted when the OSTIMER_INTR flag is set. When this bit is ‘0’, interrupt/wakeup requests due to the OSTIMER_INTR flag are blocked.A separate OSEVENT_CTRL register is implemented for each CPU. Each CPU reads its own local value at the same address.
Sourcepub const fn match_wr_rdy(&self) -> bool
pub const fn match_wr_rdy(&self) -> bool
This bit will be low when it is safe to write to reload the Match Registers. In typical applications it should not be necessary to test this bit.
Sourcepub const fn set_match_wr_rdy(&mut self, val: bool)
pub const fn set_match_wr_rdy(&mut self, val: bool)
This bit will be low when it is safe to write to reload the Match Registers. In typical applications it should not be necessary to test this bit.