#[repr(transparent)]pub struct MatchH(pub u32);Expand description
Match High Register
Tuple Fields
0: u32Implementations
Sourceimpl MatchH
impl MatchH
Sourcepub const fn match_value(&self) -> u32
pub const fn match_value(&self) -> u32
The value written to the MATCH (L/H) register pair is compared against the central EVTIMER. When a match occurs, an interrupt request is generated if enabled. A separate pair of MATCH registers are implemented for each CPU. Each CPU reads its own local value at the same pair of addresses.
Sourcepub const fn set_match_value(&mut self, val: u32)
pub const fn set_match_value(&mut self, val: u32)
The value written to the MATCH (L/H) register pair is compared against the central EVTIMER. When a match occurs, an interrupt request is generated if enabled. A separate pair of MATCH registers are implemented for each CPU. Each CPU reads its own local value at the same pair of addresses.